==> scanbot_sdk-2.8.0.tar.gz: lib/sdk_utils.dart <==
import 'dart:convert';
import 'dart:typed_data';
import 'dart:ui';

import 'package:flutter/painting.dart';
import 'package:scanbot_sdk/scanbot_sdk_models.dart';

import 'barcode_scanning_data.dart';
import 'common_data.dart';

String? toColorString(Color? color) {
  if (color != null) {
    return '#${color.value.toRadixString(16)}';
  }
  return null;
}

Color? colorFromString(String? color) {
  if (color != null) {
    var valueString = color.replaceAll('#', '');
    var value = int.parse(valueString, radix: 16);
    return Color(value);
  }
  return null;
}

Uint8List uintListFromString(String string) {
  return const Base64Decoder().convert(string);
}

Uri? stringToFileUri(String? string) {
  if (string != null) {
    return Uri.parse(string);
  }
  return null;
}

String? fileUriToString(Uri? uri) {
  return uri?.toString();
}

DateTime? dateFromString(String? string) {
  if (string != null) {
    return DateTime.parse(string);
  }
  return null;
}

String imageFilterJsonValue(ImageFilterType filter) {
  return filter.toString().replaceFirst('ImageFilterType.', '');
}

const imageFormatMap = {ImageFormat.JPG: 'JPG', ImageFormat.PNG: 'PNG'};
const contourDetectorTypeMap = {
  DocumentDetectorMode.ML_BASED: 'ML_BASED',
  DocumentDetectorMode.EDGE_BASED: 'EDGE_BASED'
};

const allDocumentFormatTypes = [
  AcceptedDocumentFormats.AAMVA,
  AcceptedDocumentFormats.BOARDING_PASS,
  AcceptedDocumentFormats.DE_MEDICAL_PLAN,
  AcceptedDocumentFormats.DISABILITY_CERTIFICATE,
  AcceptedDocumentFormats.ID_CARD_PDF_417,
  AcceptedDocumentFormats.SEPA,
  AcceptedDocumentFormats.SWISS_QR,
  AcceptedDocumentFormats.VCARD
];

==> scanbot_sdk-2.9.0.tar.gz: lib/sdk_utils.dart <==
import 'dart:convert';
import 'dart:typed_data';
import 'dart:ui';

import 'package:flutter/painting.dart';
import 'package:scanbot_sdk/scanbot_sdk_models.dart';

import 'barcode_scanning_data.dart';
import 'common_data.dart';

String? toColorString(Color? color) {
  if (color != null) {
    return '#${color.value.toRadixString(16)}';
  }
  return null;
}

Color? colorFromString(String? color) {
  if (color != null) {
    var valueString = color.replaceAll('#', '');
    var value = int.parse(valueString, radix: 16);
    return Color(value);
  }
  return null;
}

Uint8List uintListFromString(String string) {
  return const Base64Decoder().convert(string);
}

Uri? stringToFileUri(String? string) {
  if (string != null) {
    return Uri.parse(string);
  }
  return null;
}

String? fileUriToString(Uri? uri) {
  return uri?.toString();
}

DateTime? dateFromString(String? string) {
  if (string != null) {
    return DateTime.parse(string);
  }
  return null;
}

String imageFilterJsonValue(ImageFilterType filter) {
  return filter.toString().replaceFirst('ImageFilterType.', '');
}

const imageFormatMap = {ImageFormat.JPG: 'JPG', ImageFormat.PNG: 'PNG'};
const contourDetectorTypeMap = {
  DocumentDetectorMode.ML_BASED: 'ML_BASED',
  DocumentDetectorMode.EDGE_BASED: 'EDGE_BASED'
};

const allDocumentFormatTypes = [
  AcceptedDocumentFormats.AAMVA,
  AcceptedDocumentFormats.BOARDING_PASS,
  AcceptedDocumentFormats.DE_MEDICAL_PLAN,
  AcceptedDocumentFormats.MEDICAL_CERTIFICATE,
  AcceptedDocumentFormats.ID_CARD_PDF_417,
  AcceptedDocumentFormats.SEPA,
  AcceptedDocumentFormats.SWISS_QR,
  AcceptedDocumentFormats.VCARD
];
